@@ -1,5 +1,6 @@
 from __future__ import print_function, division, absolute_import
 from gevent import monkey
+
 monkey.patch_all()
 import os
 import sys
@@ -35,6 +36,21 @@ class Algorunner:
 
     @staticmethod
     def Run(start=None, init=None, stop=None, exit=None, options=None):
+        """Starts the algorunner wrapper.
+
+    Convenience method to start the algorithm. Pass the algorithm methods
+    This method blocks forever
+
+    Args:
+        start (function): The entry point of the algorithm. Called for every invocation.
+        init (function): Optional init method. Called for every invocation before the start.
+        stop (function): Optional stop method. Called when the parent pipeline is stopped.
+        exit (function): Optional exit handler. Called before the algorithm is forced to exit.
+                Can be used to clean up resources.
+
+    Returns:
+        Never returns.
+    """
         algorunner = Algorunner()
         if (start):
             algorunner.loadAlgorithmCallbacks(start, init=init, stop=stop, exit=exit, options=options or config)
@@ -153,7 +169,7 @@ class Algorunner:
 
     def _initDataServer(self, options):
         enable = options.discovery.get("enable")
-        if(enable):
+        if (enable):
             self._discovery = {
                 'host': options.discovery.get("host"),
                 'port': options.discovery.get("port")
@@ -252,7 +268,7 @@ class Algorunner:
         storageInfo = self._dataAdapter.createStorageInfo(data)
         storingData.update(storageInfo)
 
-        if(self._dataServer and savePaths):
+        if (self._dataServer and savePaths):
             self._dataServer.setSendingState(taskId, algorithmData)
             storingData.update({'discovery': self._discovery, 'taskId': taskId})
             self._sendCommand(messages.outgoing.storing, storingData)
