@@ -7,15 +7,19 @@ from hkube_python_wrapper.util.object_path import getPath, setPath
 from hkube_python_wrapper.util.encoding import Encoding
 from hkube_python_wrapper.storage.storage_manager import StorageManager
 from hkube_python_wrapper.communication.DataRequest import DataRequest
+from hkube_python_wrapper.cache.caching import Cache
+from ..config import config
+
 
 class DataAdapter:
     def __init__(self, options, dataServer=None):
         self._dataServer = dataServer
-        self._storageCache = dict()
+        self._storageCache = Cache(config.storage)
         self._encoding = Encoding(options.storage['encoding'])
         self._storageManager = StorageManager(options.storage)
         self._requestEncoding = options.discovery['encoding']
         self._requestTimeout = options.discovery['timeout']
+        self._networkTimeout = options.discovery['networkTimeout']
         self._maxWorkers = min(32, (multiprocessing.cpu_count() or 1) + 4)
         print('using {workers} for DataAdapter'.format(workers=self._maxWorkers))
 
@@ -37,7 +41,7 @@ class DataAdapter:
             return inputArgs
 
         if (useCache is False):
-            self._storageCache = dict()
+            self._storageCache = Cache(config.storage)
 
         for k, v in flatInput.items():
             if self._isStorage(v):
@@ -46,7 +50,7 @@ class DataAdapter:
                 if (link is None):
                     raise Exception('unable to find storage key')
 
-                if(typeCheck.isList(link)):
+                if (typeCheck.isList(link)):
                     data = self.batchRequest(link, jobId)
                 else:
                     data = self.tryGetDataFromPeerOrStorage(link)
@@ -91,7 +95,7 @@ class DataAdapter:
         peerResponse = self._getFromPeer(options, dataPath)
         peerError = self._getPeerError(peerResponse)
 
-        if(peerError):
+        if (peerError):
             message = peerError.get('message')
             print('batch request has failed with {message}, using storage fallback'.format(message=message))
             for t in tasks:
@@ -101,10 +105,10 @@ class DataAdapter:
             errors = peerResponse.get('errors')
             items = peerResponse.get('items')
 
-            if(errors):
+            if (errors):
                 for i, t in enumerate(items):
                     peerError = self._getPeerError(t)
-                    if(peerError):
+                    if (peerError):
                         taskId = tasks[i]
                         storageData = self._getDataForTask(jobId, taskId, dataPath)
                         batchResponse.append(storageData)
@@ -147,7 +151,7 @@ class DataAdapter:
         host = discovery.get('host')
 
         response = None
-        if(self._dataServer and self._dataServer.isLocal(host, port)):
+        if (self._dataServer and self._dataServer.isLocal(host, port)):
             response = self._dataServer.createData(taskId, tasks, dataPath)
 
         else:
@@ -160,7 +164,9 @@ class DataAdapter:
                 'taskId': taskId,
                 'dataPath': dataPath,
                 'encoding': self._requestEncoding,
-                'timeout': self._requestTimeout
+                'timeout': self._requestTimeout,
+                'networkTimeout': self._networkTimeout
+
             }
             dataRequest = DataRequest(request)
             response = dataRequest.invoke()
@@ -169,7 +175,7 @@ class DataAdapter:
 
     def _getPeerError(self, options):
         error = None
-        if(typeCheck.isDict(options)):
+        if (typeCheck.isDict(options)):
             error = options.get('hkube_error')
 
         return error
@@ -178,12 +184,10 @@ class DataAdapter:
         path = options.get('path')
         data = self._getFromCache(path)
         if (data is None):
-            data = self._getFromStorage(options)
-            self._setToCache(path, data)
-
-        if(dataPath):
+            size, data = self._getFromStorage(options)
+            self._setToCache(path, data, size)
+        if (dataPath):
             data = getPath(data, dataPath)
-
         return data
 
     @trace(name='getFromCache')
@@ -191,14 +195,15 @@ class DataAdapter:
     def _getFromCache(self, path):
         return self._storageCache.get(path)
 
-    def _setToCache(self, path, data):
-        self._storageCache[path] = data
+    def _setToCache(self, path, data, size):
+        self._storageCache.update(path, data, size)
 
     @trace(name='getFromStorage')
     @timing
     def _getFromStorage(self, options):
         response = self._storageManager.storage.get(options)
-        return self._encoding.decode(response)
+        size = len(response)
+        return (size, self._encoding.decode(response))
 
     def createStorageInfo(self, options):
         jobId = options.get('jobId')
@@ -237,9 +242,9 @@ class DataAdapter:
         return metadata
 
     def _getMetadata(self, value):
-        if(typeCheck.isDict(value)):
+        if (typeCheck.isDict(value)):
             meta = {'type': 'object'}
-        elif(typeCheck.isList(value)):
+        elif (typeCheck.isList(value)):
             meta = {'type': 'array', 'size': len(value)}
         else:
             meta = {'type': str(type(value).__name__)}
